# Puppet Comply

Puppet Comply is a tool that assesses the infrastructure you manage with Puppet Enterprise against CIS Benchmarks — the best practices for securely configuring systems from the Center for Internet Security (CIS).

## Installing

This Module is required by the Puppet Comply product and should only be used as per the [complete install instructions](https://puppet.com/docs/comply/latest/comply.html)

There are two workflows for using the Comply module:

### Using Replicated to host the Assessor

This is the default recommend workflow for using Comply. Comply hosts a copy of the latest Assessor. This path enables you to configure once, and allow Comply to easily upgrade your Assessor when you do a product upgrade. You can configure the service hosting the Assessor via KOTS to use certificates generated on your PE instance. Then, mutual TLS enables a secure authenticated between your nodes and Comply.

To generate the certificates on your PE instance, run the following:

```
[root@pe-instance-01 ~]# puppetserver ca generate --certname comply.10.234.4.193.nip.io
Successfully saved private key for comply.10.234.4.193.nip.io to /etc/puppetlabs/puppet/ssl/private_keys/comply.10.234.4.193.nip.io.pem
Successfully saved public key for comply.10.234.4.193.nip.io to /etc/puppetlabs/puppet/ssl/public_keys/comply.10.234.4.193.nip.io.pem
Successfully submitted certificate request for comply.10.234.4.193.nip.io
Successfully saved certificate for comply.10.234.4.193.nip.io to /etc/puppetlabs/puppet/ssl/certs/comply.10.234.4.193.nip.io.pem
Certificate for comply.10.234.4.193.nip.io was autosigned.
```

Then copy the `ca.pem`, public certificate and private key for your Comply instance to the KOTS config. Once deployed, the service will now be accessible to your nodes.

In order to keep you up to date, the version of the Assessor is embedded in the module. As such, when doing an upgrade of the Comply product, you should ensure that you have upgraded the module beforehand.

### Using a privately hosted file

Alternatively, you can host the file privately elsewhere. If you choose this method, then use `scanner_source` parameter with the `comply` class. You may also need to disable the `use_mtls` paramter too. The version of the Assessor is inferred from the file name so for example if your `scanner_source` value was `https://files.company.net/assessors/Assessor-CLI-v4.6.0.zip`, Comply would infer this as being version `4.6.0` of the Assessor.

## Configuration

By default, Comply will install various dependencies required in order for the module and the CIS Assessor to function. Should you wish to configure what Comply manages, see the [reference](REFERENCE.md) for more details.

## Obtaining the Product

Please [get in touch with a Puppet Representative](https://puppet.com/contact-sales/)

## Running Acceptance Tests
```
bundle exec rake litmus:tear_down;
bundle exec rake litmus:provision_list[release_checks]; #reduce hosts in provision.yaml if required
bundle exec rake litmus:install_agent[puppet7];
bundle exec rake litmus:install_module;
bundle exec rake litmus:acceptance:parallel; #bundle exec rake litmus:acceptance:rid-fraternity.delivery.puppetlabs.net
```



